# coding=utf-8
from setuptools import setup, find_packages

setup(
    name='abupy',
    version='0.0.1',
    keywords=('阿布', 'abu', 'quant', 'quantization', '量化', '爬虫', 'crawler', 'spider', 'scrapy', 'stock', '股票',
                'ML', '机器学习', '深度学习', 'machine learning', 'deep learning'),
    description='股票量化',

    author=u'阿布',
    author_email='steven.wu.ven@gmail.com',

    packages=find_packages(),
    platforms='any',
)
